@@ -2,11 +2,11 @@
 #######################################################################
 """Interfaces for the Zope 3 based product package
 
-$Id: interfaces.py 49270 2008-01-08 12:53:09Z cray $
+$Id: interfaces.py 49685 2008-01-23 14:31:46Z cray $
 """
 __author__  = "Elena Antusheva, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 49270 $"
+__version__ = "$Revision: 49685 $"
  
 from zope.interface import Interface
 
@@ -35,4 +35,7 @@ class ISmartBannerContainer ( IOrderedContainer ) :
     """ """
     def __setitem__(name, object) :
         """ Add a ISmartBannerContent object. """
-    __setitem__.precondition = ItemTypePrecondition(ISmartBannerContent)
\ No newline at end of file
+    __setitem__.precondition = ItemTypePrecondition(ISmartBannerContent)
+    
+class ISmartBannerContainerOrdered ( ISmartBannerContainer ) :
+    """ """    
\ No newline at end of file
